/* A test program to test the get and set functions. */

#include <stdio.h>
#include <glib.h>
#include <string.h>
#include <stdlib.h>
#include "ca_libs.h"
#include "ca_dictSyms.h"
#include "ca_macros.h"

#define DEBUG	/* Debug this file. */

int main ()
{
FILE *cfPtr;
int port;
char help[80];
char reply[80];

ca_getDictionary(dictionary, VARS);

ca_getDatabase(ripe);
ca_getDatabase(arin);
ca_getDatabase(radb);

ca_getSource(ripeComponent);
ca_getSource(arinComponent);
ca_getSource(radbComponent);

sourceList = g_slist_append(sourceList, &ripeComponent);
sourceList = g_slist_append(sourceList, &arinComponent);
sourceList = g_slist_append(sourceList, &radbComponent);

ca_getAllSources(sourceList);

ca_get_bindport;
ca_set_bindport;
ca_get_bindport;

ca_get_help;
ca_set_help;
ca_get_help;

ca_get_replybanner;
ca_set_replybanner;
ca_get_replybanner;

/*
 * ca_get_source;
 * ca_set_source;
 * ca_get_source;
 */

ca_get_testmode;
ca_set_testmode;
ca_get_testmode;

ca_get_overridecryptedpw;
ca_set_overridecryptedpw;
ca_get_overridecryptedpw;

ca_get_whoishelp;
ca_set_whoishelp;
ca_get_whoishelp;

ca_get_autodbmhelp;
ca_set_autodbmhelp;
ca_get_autodbmhelp;

ca_get_attdesc;
ca_set_attdesc;
ca_get_attdesc;

/*
 * ca_get_deflook;
 * ca_set_deflook;
 * ca_get_deflook;
 */

ca_get_dbfile;
ca_set_dbfile;
ca_get_dbfile;

/*
 * ca_get_canupd;
 * ca_set_canupd;
 * ca_get_canupd;
 * 
 * ca_get_crossnotifysources;
 * ca_set_crossnotifysources;
 * ca_get_crossnotifysources;
 */

ca_get_uid;
ca_set_uid;
ca_get_uid;

ca_get_qrylog;
ca_set_qrylog;
ca_get_qrylog;

ca_get_qry2log;
ca_set_qry2log;
ca_get_qry2log;

ca_get_errlog;
ca_set_errlog;
ca_get_errlog;

ca_get_auditlog;
ca_set_auditlog;
ca_get_auditlog;

ca_get_updlog;
ca_set_updlog;
ca_get_updlog;

ca_get_acklog;
ca_set_acklog;
ca_get_acklog;

ca_get_lockdir;
ca_set_lockdir;
ca_get_lockdir;

ca_get_pidfile;
ca_set_pidfile;
ca_get_pidfile;

ca_get_updatelock;
ca_set_updatelock;
ca_get_updatelock;

ca_get_cleanlock;
ca_set_cleanlock;
ca_get_cleanlock;

ca_get_serialdir;
ca_set_serialdir;
ca_get_serialdir;

ca_get_oldserialdir;
ca_set_oldserialdir;
ca_get_oldserialdir;

ca_get_serialincomingdir;
ca_set_serialincomingdir;
ca_get_serialincomingdir;

ca_get_keepopen;
ca_set_keepopen;
ca_get_keepopen;

ca_get_allocmnt;
ca_set_allocmnt;
ca_get_allocmnt;

ca_get_getupdatesfrom;
ca_set_getupdatesfrom;
ca_get_getupdatesfrom;

ca_get_whoisupdfrom;
ca_set_whoisupdfrom;
ca_get_whoisupdfrom;

ca_get_denywhoisaccess;
ca_set_denywhoisaccess;
ca_get_denywhoisaccess;

ca_get_tmpdir;
ca_set_tmpdir;
ca_get_tmpdir;

ca_get_pgpv;
ca_set_pgpv;
ca_get_pgpv;

ca_get_pgpk;
ca_set_pgpk;
ca_get_pgpk;

ca_get_pgppath;
ca_set_pgppath;
ca_get_pgppath;

ca_get_mailcmd;
ca_set_mailcmd;
ca_get_mailcmd;

ca_get_overflowsize;
ca_set_overflowsize;
ca_get_overflowsize;

ca_get_dbcachesize;
ca_set_dbcachesize;
ca_get_dbcachesize;

ca_get_nrofnames;
ca_set_nrofnames;
ca_get_nrofnames;

ca_get_defmail;
ca_set_defmail;
ca_get_defmail;

ca_get_humailbox;
ca_set_humailbox;
ca_get_humailbox;

ca_get_autobox;
ca_set_autobox;
ca_get_autobox;

ca_get_duplicatepersoncheck;
ca_set_duplicatepersoncheck;
ca_get_duplicatepersoncheck;

ca_get_replybanner;
ca_set_replybanner;
ca_get_replybanner;

ca_get_nomatch;
ca_set_nomatch;
ca_get_nomatch;

ca_get_cn_subject_add;
ca_set_cn_subject_add;
ca_get_cn_subject_add;

ca_get_cn_subject_del;
ca_set_cn_subject_del;
ca_get_cn_subject_del;

ca_get_cn_explain_add;
ca_set_cn_explain_add;
ca_get_cn_explain_add;

ca_get_cn_explain_del;
ca_set_cn_explain_del;
ca_get_cn_explain_del;

ca_get_cn_overlap_add;
ca_set_cn_overlap_add;
ca_get_cn_overlap_add;

ca_get_cn_overlap_del;
ca_set_cn_overlap_del;
ca_get_cn_overlap_del;

ca_get_cno_subject_add;
ca_set_cno_subject_add;
ca_get_cno_subject_add;

ca_get_cno_subject_del;
ca_set_cno_subject_del;
ca_get_cno_subject_del;

ca_get_cno_explain_add;
ca_set_cno_explain_add;
ca_get_cno_explain_add;

ca_get_cno_explain_del;
ca_set_cno_explain_del;
ca_get_cno_explain_del;

ca_get_cno_overlap_add;
ca_set_cno_overlap_add;
ca_get_cno_overlap_add;

ca_get_cno_overlap_del;
ca_set_cno_overlap_del;
ca_get_cno_overlap_del;

ca_get_mailtxt;
ca_set_mailtxt;
ca_get_mailtxt;

ca_get_mheader;
ca_set_mheader;
ca_get_mheader;

ca_get_failuretxt;
ca_set_failuretxt;
ca_get_failuretxt;

ca_get_successtxt;
ca_set_successtxt;
ca_get_successtxt;

ca_get_helpheader;
ca_set_helpheader;
ca_get_helpheader;

ca_get_ackerr;
ca_set_ackerr;
ca_get_ackerr;

ca_get_ackok;
ca_set_ackok;
ca_get_ackok;

ca_get_acksig;
ca_set_acksig;
ca_get_acksig;

ca_get_notitxt;
ca_set_notitxt;
ca_get_notitxt;

ca_get_notimailtxt;
ca_set_notimailtxt;
ca_get_notimailtxt;

ca_get_notinetworktxt;
ca_set_notinetworktxt;
ca_get_notinetworktxt;

ca_get_nheader;
ca_set_nheader;
ca_get_nheader;

ca_get_fwheader;
ca_set_fwheader;
ca_get_fwheader;

ca_get_fwtxt;
ca_set_fwtxt;
ca_get_fwtxt;

ca_get_fwmailtxt;
ca_set_fwmailtxt;
ca_get_fwmailtxt;

ca_get_fwnetworktxt;
ca_set_fwnetworktxt;
ca_get_fwnetworktxt;

ca_get_mtfwheader;
ca_set_mtfwheader;
ca_get_mtfwheader;

ca_get_mtfwtxt;
ca_set_mtfwtxt;
ca_get_mtfwtxt;

ca_get_denyaccesstxt;
ca_set_denyaccesstxt;
ca_get_denyaccesstxt;

ca_get_referraltxt;
ca_set_referraltxt;
ca_get_referraltxt;

ca_get_referralerrortxt;
ca_set_referralerrortxt;
ca_get_referralerrortxt;

ca_get_referrallooperrortxt;
ca_set_referrallooperrortxt;
ca_get_referrallooperrortxt;

ca_get_referraltimeouttxt;
ca_set_referraltimeouttxt;
ca_get_referraltimeouttxt;

ca_get_referraltrunctxt;
ca_set_referraltrunctxt;
ca_get_referraltrunctxt;

ca_get_referralendtxt;
ca_set_referralendtxt;
ca_get_referralendtxt;

ca_get_referraltimeout;
ca_set_referraltimeout;
ca_get_referraltimeout;

ca_get_referralmaxlines;
ca_set_referralmaxlines;
ca_get_referralmaxlines;

ca_get_rights;
ca_set_rights;
ca_get_rights;

ca_get_country;
ca_set_country;
ca_get_country;


return (0);
}
